@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2016 The OpenMx Project
+#   Copyright 2007-2017 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -73,7 +73,7 @@ growthCurveModel <- mxModel("Linear Growth Curve Model Path Specification",
 growthCurveFit <- mxRun(growthCurveModel, suppressWarnings=TRUE)
 
 summary(growthCurveFit)
-growthCurveFit$output$estimate
+coef(growthCurveFit)
 
 
 omxCheckCloseEnough(growthCurveFit$output$estimate[["meani"]], 9.930, 0.01)
@@ -83,4 +83,4 @@ omxCheckCloseEnough(growthCurveFit$output$estimate[["vars"]], 0.258, 0.01)
 omxCheckCloseEnough(growthCurveFit$output$estimate[["cov"]], 0.460, 0.01)
 omxCheckCloseEnough(growthCurveFit$output$estimate[["residual"]], 2.316, 0.01)
 # Compare OpenMx results to Mx results 
-# -----------------------------------------------------------------------------
\ No newline at end of file
+# -----------------------------------------------------------------------------
