@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2016 The OpenMx Project
+#   Copyright 2007-2017 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -21,4 +21,10 @@ identity <- diag(2)
 dimnames(identity) <- list(c('a','b'),c('a','b'))
 data <- mxData(identity, 'cov', numObs = 10)
 model <- mxModel('model', cov, objective, data,  mxFitFunctionML())
-ign <- omxCheckWarning(mxRun(model), "In model 'model' Optimizer returned a non-zero status code 10. Starting values are not feasible. Consider mxTryHard()")
+ign <- omxCheckWarning(omxCheckError(mxRun(model), "The job for model 'model' exited abnormally with the error message: fit is not finite (model.fitfunction: stan::prob::multi_normal_sufficient_log: LDLT_Factor of covariance parameter is not positive definite. last conditional variance is 0.)"),
+		       "In model 'model' Optimizer returned a non-zero status code 10. Starting values are not feasible. Consider mxTryHard()")
+
+dimnames(identity) <- list(c('a','c'),c('a','c'))
+data <- mxData(identity, 'cov', numObs = 10)
+model <- mxModel('model', cov, objective, data,  mxFitFunctionML())
+ign <- omxCheckError(mxRun(model), "The dimnames for the expected covariance matrix ('a' and 'b') and the observed covariance matrix ('a' and 'c') in the Normal expectation function in model 'model' are not identical.")
