@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2016 The OpenMx Project
+#   Copyright 2007-2017 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -38,20 +38,16 @@ model1 <- mxModel('model1', A)
 model2 <- mxModel('model2', B)
 model <- mxModel('model', model1, model2)
 omxCheckError(mxRun(model),
-	paste("A cycle has been detected",
-		"in model 'model' involving the",
-		"following elements: 'model2.B'",
-		"and 'model1.A'"))
+	      "A cycle has been detected in model 'model' . It involved the following elements: 'model2.B' and 'model1.A'
+A common trigger for this error is not providing a name string as the first parameter to mxModel.")
 
 A <- mxMatrix('Full', 1, 1, labels = 'B[1,1]', name = 'A')
 B <- mxMatrix('Full', 1, 1, labels = 'C[1,1]', name = 'B')
 C <- mxMatrix('Full', 1, 1, labels = 'A[1,1]', name = 'C')
 model <- mxModel('model', A, B, C)
 omxCheckError(mxRun(model),
-	paste("A cycle has been detected",
-		"in model 'model' involving the",
-		"following elements: 'B',",
-		"'C', and 'A'"))
+	      "A cycle has been detected in model 'model' . It involved the following elements: 'B', 'C', and 'A'
+A common trigger for this error is not providing a name string as the first parameter to mxModel.")
 
 A <- mxMatrix('Full', 2, 2, name = 'A')
 B <- mxMatrix('Full', 2, 2, name = 'B')
