@@ -215,7 +215,7 @@ double GradientOptimizerContext::solFun(double *myPars, int* mode)
 	Eigen::Map< Eigen::VectorXd > Est(myPars, fc->numParam);
 	if (*mode == 1) {
 		fc->iterations += 1;
-		Global->reportProgress("MxComputeGradientDescent", fc);
+		Global->reportProgress(optName, fc);
 	}
 	copyFromOptimizer(myPars, fc);
 
@@ -260,7 +260,7 @@ void GradientOptimizerContext::solEqBFun(bool wantAJ) //<--"want analytic Jacobi
 	/*Note that this needs to happen even if no equality constraints have analytic Jacobians, because
 	analyticEqJacTmp is copied to the Jacobian matrix the elements of which are populated by code in
 	finiteDifferences.h, which knows to numerically populate an element if it's NA:*/
-	analyticEqJacTmp.setConstant(analyticEqJacTmp.rows(),analyticEqJacTmp.cols(),NA_REAL);
+	analyticEqJacTmp.setConstant(NA_REAL);
 	
 	int cur=0, j=0, c=0, roffset=0;
 	for(j = 0; j < int(st->conListX.size()); j++) {
@@ -294,7 +294,7 @@ void GradientOptimizerContext::myineqFun(bool wantAJ)
 
 	if (!ineq_n) return;
 	
-	analyticIneqJacTmp.setConstant(analyticIneqJacTmp.rows(),analyticIneqJacTmp.cols(),NA_REAL);
+	analyticIneqJacTmp.setConstant(NA_REAL);
 	
 	int cur=0, j=0, c=0, roffset=0;
 	for (j=0; j < int(st->conListX.size()); j++) {
@@ -518,7 +518,7 @@ void omxComputeGD::computeImpl(FitContext *fc)
 
 	if (verbose >= 1) {
 		int numConstr = fitMatrix->currentState->conListX.size();
-		mxLog("%s: engine %s (ID %d) #P=%d gradient=%s tol=%g constraints=%d",
+		mxLog("%s: engine %s (ID %d) #P=%lu gradient=%s tol=%g constraints=%d",
 		      name, engineName, engine, numParam, gradientAlgoName, optimalityTolerance,
 		      numConstr);
 	}
@@ -908,7 +908,7 @@ void ComputeCI::recordCI(Method meth, ConfidenceInterval *currentCI, int lower,
 	}
 	INTEGER(VECTOR_ELT(detail, 4+fc.numParam))[detailRow] = meth;
 	INTEGER(VECTOR_ELT(detail, 5+fc.numParam))[detailRow] = diag;
-	INTEGER(VECTOR_ELT(detail, 6+fc.numParam))[detailRow] = 1 + fc.getInform();
+	INTEGER(VECTOR_ELT(detail, 6+fc.numParam))[detailRow] = fc.wrapInform();
 	++detailRow;
 }
 
@@ -1592,21 +1592,7 @@ void ComputeCI::computeImpl(FitContext *mle)
 	SET_VECTOR_ELT(detail, 5+mle->numParam,
 		       makeFactor(Rf_allocVector(INTSXP, totalIntervals),
 				  OMX_STATIC_ARRAY_SIZE(diagLabels), diagLabels));
-	const char *statusCodeLabels[] = { // see ComputeInform type
-		"OK", "OK/green",
-		"infeasible linear constraint",
-		"infeasible non-linear constraint",
-		"iteration limit",
-		"not convex",
-		"nonzero gradient",
-		"bad deriv",
-		"?",
-		"internal error",
-		"infeasible start"
-	};
-	SET_VECTOR_ELT(detail, 6+mle->numParam,
-		       makeFactor(Rf_allocVector(INTSXP, totalIntervals),
-				  OMX_STATIC_ARRAY_SIZE(statusCodeLabels), statusCodeLabels));
+	SET_VECTOR_ELT(detail, 6+mle->numParam, allocInformVector(totalIntervals));
 
 	SEXP detailCols;
 	Rf_protect(detailCols = Rf_allocVector(STRSXP, numDetailCols));
@@ -1733,6 +1719,8 @@ class ComputeTryH : public omxCompute {
 	Eigen::ArrayXd bestEst;
 	int bestStatus;
 	double bestFit;
+	Eigen::VectorXd solLB;
+	Eigen::VectorXd solUB;
 
 	static bool satisfied(FitContext *fc);
 public:
@@ -1742,6 +1730,7 @@ public:
 	virtual void computeImpl(FitContext *fc);
 	virtual void reportResults(FitContext *fc, MxRList *slots, MxRList *out);
 	virtual void collectResults(FitContext *fc, LocalComputeResult *lcr, MxRList *out);
+	void copyBounds(FitContext *fc);
 };
 
 omxCompute *newComputeTryHard()
@@ -1793,6 +1782,10 @@ void ComputeTryH::computeImpl(FitContext *fc)
 	Map< ArrayXd > curEst(fc->est, fc->numParam);
 	ArrayXd origStart = curEst;
 	bestEst = curEst;
+	
+	solLB.resize(curEst.size());
+	solUB.resize(curEst.size());
+	copyBounds(fc);
 
 	++invocations;
 
@@ -1829,6 +1822,8 @@ void ComputeTryH::computeImpl(FitContext *fc)
 				mxLog("%d %g %g", vx, adj1, adj2);
 			}
 			curEst[vx] = curEst[vx] * adj1 + adj2;
+			if(curEst[vx] < solLB[vx]){curEst[vx] = solLB[vx];}
+			if(curEst[vx] > solUB[vx]){curEst[vx] = solUB[vx];}
 		}
 
 		--retriesRemain;
@@ -1872,3 +1867,16 @@ void ComputeTryH::reportResults(FitContext *fc, MxRList *slots, MxRList *out)
 	info.add("retries", Rf_ScalarInteger(numRetries));
 	slots->add("debug", info.asR());
 }
+
+void ComputeTryH::copyBounds(FitContext *fc)
+{
+	int px=0;
+	for (size_t vx=0; vx < fc->profiledOut.size(); ++vx) {
+		if (fc->profiledOut[vx]) continue;
+		solLB[px] = varGroup->vars[vx]->lbound;
+		if (!std::isfinite(solLB[px])) solLB[px] = NEG_INF;
+		solUB[px] = varGroup->vars[vx]->ubound;
+		if (!std::isfinite(solUB[px])) solUB[px] = INF;
+		++px;
+	}
+}
