@@ -21,6 +21,13 @@
 //#include <Eigen/LU>
 #include "EnableWarnings.h"
 
+void omxRAMExpectation::flatten(FitContext *fc)
+{
+	if (rram) return;
+	rram = new RelationalRAMExpectation::state;
+	rram->init(this, fc);
+}
+
 void omxRAMExpectation::compute(FitContext *fc, const char *what, const char *how)
 {
 	omxRAMExpectation* oro = this;
@@ -31,10 +38,7 @@ void omxRAMExpectation::compute(FitContext *fc, const char *what, const char *ho
 		if (strEQ(what, "distribution")) { wantCov = true; wantMean = true; }
 		if (strEQ(what, "covariance")) wantCov = true;
 		if (strEQ(what, "mean")) wantMean = true;
-		if (!oro->rram) {
-			oro->rram = new RelationalRAMExpectation::state;
-			oro->rram->init(this, fc);
-		}
+		flatten(fc);
 		if (wantCov)  oro->rram->computeCov(fc);
 		if (wantMean) oro->rram->computeMean(fc);
 		return;
@@ -43,6 +47,14 @@ void omxRAMExpectation::compute(FitContext *fc, const char *what, const char *ho
 	oro->CalculateRAMCovarianceAndMeans(fc);
 }
 
+void omxRAMExpectation::invalidateCache()
+{
+	if (rram) {
+		delete rram;
+		rram = 0;
+	}
+}
+
 omxRAMExpectation::~omxRAMExpectation()
 {
 	if(OMX_DEBUG) { mxLog("Destroying RAM Expectation."); }
@@ -351,6 +363,18 @@ omxMatrix* omxRAMExpectation::getComponent(const char* component)
 	return retval;
 }
 
+
+void omxRAMExpectation::generateData(FitContext *fc, MxRList &out)
+{
+	if (!between.size()) {
+		super::generateData(fc, out);
+	}
+
+	flatten(fc);
+
+	rram->simulate(fc, out);
+}
+
 namespace RelationalRAMExpectation {
 
 	omxExpectation *addr::getModel(FitContext *fc)
@@ -513,6 +537,7 @@ namespace RelationalRAMExpectation {
 		as1.fk1 = NA_INTEGER;
 		as1.numJoins = 0;
 		as1.numKids = 0;
+		as1.heterogenousMean = false;
 		a1.rampartScale = 1.0;
 		a1.row = frow;
 		a1.setModel(expectation);
@@ -768,6 +793,10 @@ namespace RelationalRAMExpectation {
 				addr *lp = joinedWith(la, jx);
 				addr *rp = joinedWith(ra, jx);
 				if (!lp && !rp) continue;
+				if (!lp || !rp) {
+					mismatch = true;
+					return !lp;
+				}
 				bool got = compareDeep(*lp, *rp, mismatch);
 				if (mismatch) return got;
 			}
@@ -912,15 +941,18 @@ namespace RelationalRAMExpectation {
 	}
 
 	template <typename T>
-	void state::placeSet(std::set<std::vector<T> > &toPlace, independentGroup *ig)
+	bool state::placeSet(std::set<std::vector<T> > &toPlace, independentGroup *ig)
 	{
+		bool heterogenousMean = false;
 		for (std::set<std::vector<int> >::iterator px = toPlace.begin();
 		     px != toPlace.end(); ++px) {
 			const std::vector<int> &clump = *px;
 			for (size_t cx=0; cx < clump.size(); ++cx) {
+				heterogenousMean |= layoutSetup[ clump[cx] ].heterogenousMean;
 				ig->place(clump[cx]);
 			}
 		}
+		return heterogenousMean;
 	}
 
 	// 2nd visitor
@@ -1015,21 +1047,21 @@ namespace RelationalRAMExpectation {
 				}
 				placeSet(mit->second, ig);
 			}
-			ig->sufficientSets.resize(ssCount);
-			int ssIndex = 0;
+			ig->sufficientSets.reserve(ssCount);
 			for (CompatibleMeanMapType::iterator mit = cmm.begin();
 			     mit != cmm.end(); ++mit) {
 				if (mit->second.size() == 1) continue;
 				int from = ig->placements.size();
-				placeSet(mit->second, ig);
+				if (placeSet(mit->second, ig)) continue;
 				if (verbose() >= 3) {
 					mxLog("group %d same mean %d -> %d clumpsize %d",
 					      int(group.size()), from, int(ig->placements.size() - 1),
 					      int(it->second.begin()->size()));
 				}
-				ig->sufficientSets[ssIndex].start = from / ig->clumpSize;
-				ig->sufficientSets[ssIndex].length = (ig->placements.size() - from) / ig->clumpSize;
-				++ssIndex;
+				sufficientSet ss;
+				ss.start = from / ig->clumpSize;
+				ss.length = (ig->placements.size() - from) / ig->clumpSize;
+				ig->sufficientSets.push_back(ss);
 			}
 			if (!ram->useSufficientSets) ig->sufficientSets.clear();
 			ig->prep(fc);
@@ -1295,9 +1327,22 @@ namespace RelationalRAMExpectation {
 	template <typename T>
 	void state::oertzenRotate(std::vector<T> &t1)
 	{
-		// get covariance and sort by mahalanobis distance TODO
 		rotationPlan.push_back(t1);
+
 		addrSetup &specimen = layoutSetup[ t1[0] ];
+		CompatibleMeanCompare cmp(this);
+
+		bool mismatch = false;
+		for (int cx=1; cx < int(t1.size()); ++cx) {
+			cmp.compareDeep(layout[ t1[0] ], layout[ t1[cx] ], mismatch);
+			if (mismatch) break;
+		}
+		if (mismatch) {
+			for (int cx=0; cx < int(t1.size()); ++cx) {
+				layoutSetup[ t1[cx] ].heterogenousMean = true;
+			}
+		}
+
 		for (size_t cx=0; cx < specimen.clump.size(); ++cx) {
 			std::vector<int> t2;
 			t2.reserve(t1.size());
@@ -1387,6 +1432,34 @@ namespace RelationalRAMExpectation {
 		};
 	};
 
+	template <typename T>
+	void state::unapplyRotationPlan(T accessor)
+	{
+		for (size_t rx=0; rx < rotationPlan.size(); ++rx) {
+			const std::vector<int> &units = rotationPlan[rx];
+			int numUnits = units.size();
+			const addr &specimen = layout[units[0]];
+			for (int ox=0; ox < specimen.numObs(); ++ox) {
+				double p1 = sqrt(1.0/numUnits) * accessor(units[0], ox);
+				for (int ii = 0; ii < numUnits; ii++) {
+					double k = numUnits-ii;
+					if (ii >= 1 && ii < numUnits-1) {
+						p1 += sqrt(1.0/(k*(k+1))) * accessor(units[ii], ox);
+					}
+					double p2;
+					if (ii >= numUnits-2) {
+						p2 = M_SQRT1_2;
+						if (ii == numUnits - 1) p2 = -p2;
+					} else {
+						p2 = -sqrt((k-1.0)/k);
+					}
+					accessor(units[ii], ox) =
+						p1 + p2 * accessor(units[std::min(ii+1, numUnits-1)], ox);
+				}
+			}
+		}
+	}
+
 	template <typename T>
 	void state::applyRotationPlan(T accessor)
 	{
@@ -1504,6 +1577,8 @@ namespace RelationalRAMExpectation {
 		}
 
 		applyRotationPlan(UnitAccessor<false>(this));
+		//unapplyRotationPlan(UnitAccessor<false>(this));
+		//applyRotationPlan(UnitAccessor<false>(this));
 
 		for (std::vector<independentGroup*>::iterator it = group.begin() ; it != group.end(); ++it) {
 			(*it)->finalizeData();
@@ -1559,6 +1634,109 @@ namespace RelationalRAMExpectation {
 		//{ Eigen::MatrixXd tmp = fullCov; mxPrintMat("fullcov", tmp); }
 	}
 
+	void independentGroup::simulate()
+	{
+		if (!dataVec.size()) return;
+
+		simDataVec = expectedVec;
+
+		SimpCholesky< Eigen::MatrixXd > covDecomp;
+		Eigen::MatrixXd denseCov = fullCov;
+		covDecomp.compute(denseCov);
+		if (covDecomp.info() != Eigen::Success || !(covDecomp.vectorD().array() > 0.0).all()) {
+			omxRaiseErrorf("%s: covariance is non-positive definite", st.homeEx->name);
+			return;
+		}
+
+		Eigen::MatrixXd res(fullCov.rows(), fullCov.cols());
+		res.setIdentity();
+		res = covDecomp.transpositionsP() * res;
+		// L^* P
+		res = covDecomp.matrixU() * res;
+		// D(L^*P)
+		res = covDecomp.vectorD().array().sqrt().matrix().asDiagonal() * res;
+
+		Eigen::VectorXd sim1(clumpObs);
+		int clumps = placements.size() / clumpSize;
+		for (int cx=0; cx < clumps; ++cx) {
+			for (int ob=0; ob < clumpObs; ++ob) {
+				sim1[ob] = Rf_rnorm(0, 1.0);
+			}
+			simDataVec.segment(cx*clumpObs, clumpObs) += sim1.transpose() * res;
+		}
+	}
+
+	struct SimUnitAccessor {
+		state &st;
+		SimUnitAccessor(state *_st) : st(*_st) {};
+
+		double &operator() (const int unit, const int obs)
+		{
+			addr &ad = st.getParent().layout[unit];
+			independentGroup &ig = *ad.ig;
+			int obsStart = ig.placements[ad.igIndex].obsStart;
+			return ig.simDataVec.coeffRef(obsStart + obs);
+		};
+	};
+
+	void state::simulate(FitContext *fc, MxRList &out)
+	{
+		computeMean(fc);
+
+		for (auto &ig : group) {
+			ig->computeCov1(fc);
+			ig->computeCov2();
+			ig->simulate();
+		}
+
+		unapplyRotationPlan(SimUnitAccessor(this));
+
+		std::map<omxExpectation*, SEXP> DataMap;
+		for (auto &ex1 : allEx) {
+			auto &dc = ex1->getDataColumns();
+			if (dc.size() == 0) continue;
+			omxData *data = ex1->data;
+
+			SEXP df;
+			Rf_protect(df = Rf_allocVector(VECSXP, dc.size()));
+			SEXP colnames = Rf_allocVector(STRSXP, dc.size());
+			Rf_setAttrib(df, R_NamesSymbol, colnames);
+			for (int col=0; col < int(dc.size()); ++col) {
+				SEXP colData = Rf_allocVector(REALSXP, data->rows);
+				SET_VECTOR_ELT(df, col, colData);
+				double *colPtr = REAL(colData);
+				for (int rx=0; rx < data->rows; ++rx) {
+					colPtr[rx] = NA_REAL;
+				}
+				SET_STRING_ELT(colnames, col, Rf_mkChar(omxDataColumnName(data, dc[col])));
+			}
+			markAsDataFrame(df, data->rows);
+
+			DataMap[ex1] = df;
+			out.add(data->name, df);
+		}
+
+		// NOTE: Does not copy foreign and primaryKeys
+
+		for (auto &ig : group) {
+			if (0 == ig->dataVec.size()) continue;
+			for (int px=0; px < int(ig->gMap.size()); ++px) {
+				addr &a1 = layout[ ig->gMap[px] ];
+				omxRAMExpectation *ram = a1.getRAMExpectationReadOnly();
+				SEXP df = DataMap[ram];
+				auto &pl = ig->placements[px];
+				for (int vx=0, ncol=0, dx=0; vx < ram->F->cols; ++vx) {
+					if (!ram->latentFilter[vx]) continue;
+					int col = ncol++;
+					if (!ig->latentFilter[ pl.modelStart + vx ]) continue;
+
+					REAL(VECTOR_ELT(df, col))[a1.row] = ig->simDataVec[dx];
+					dx += 1;
+				}
+			}
+		}
+	}
+
 	void state::computeCov(FitContext *fc)
 	{
 		for (size_t gx=0; gx < group.size(); ++gx) {
@@ -1752,7 +1930,7 @@ namespace RelationalRAMExpectation {
 		dbg.add("rampartUsage", Rcpp::wrap(rampartUsage));
 		dbg.add("numGroups", Rcpp::wrap(int(group.size())));
 
-		SEXP modelName, row, numJoins, numKids, parent1, fk1, rscale, ugroup;
+		SEXP modelName, row, numJoins, numKids, parent1, fk1, rscale, hmean, ugroup;
 		Rf_protect(modelName = Rf_allocVector(STRSXP, layout.size()));
 		Rf_protect(row = Rf_allocVector(INTSXP, layout.size()));
 		Rf_protect(numKids = Rf_allocVector(INTSXP, layout.size()));
@@ -1760,6 +1938,7 @@ namespace RelationalRAMExpectation {
 		Rf_protect(parent1 = Rf_allocVector(INTSXP, layout.size()));
 		Rf_protect(fk1 = Rf_allocVector(INTSXP, layout.size()));
 		Rf_protect(rscale = Rf_allocVector(REALSXP, layout.size()));
+		Rf_protect(hmean = Rf_allocVector(INTSXP, layout.size()));
 		Rf_protect(ugroup = Rf_allocVector(INTSXP, layout.size()));
 		for (size_t mx=0; mx < layout.size(); ++mx) {
 			SET_STRING_ELT(modelName, mx, Rf_mkChar(layout[mx].modelName().c_str()));
@@ -1769,6 +1948,7 @@ namespace RelationalRAMExpectation {
 			INTEGER(parent1)[mx] = plusOne(layoutSetup[mx].parent1);
 			INTEGER(fk1)[mx] = layoutSetup[mx].fk1;
 			REAL(rscale)[mx] = layout[mx].rampartScale;
+			INTEGER(hmean)[mx] = layoutSetup[mx].heterogenousMean;
 			INTEGER(ugroup)[mx] = layout[mx].ig? 1+layout[mx].ig->arrayIndex : NA_INTEGER;
 		}
 		dbg.add("layout", Rcpp::DataFrame::create(Rcpp::Named("model")=modelName,
@@ -1778,6 +1958,7 @@ namespace RelationalRAMExpectation {
 							  Rcpp::Named("parent1")=parent1,
 							  Rcpp::Named("fk1")=fk1,
 							  Rcpp::Named("rampartScale")=rscale,
+							  Rcpp::Named("hmean")=hmean,
 							  Rcpp::Named("group")=ugroup));
 
 		int digits = ceilf(log10f(group.size()));
